TestClient class

Constructors

TestClient(String url, Client client)
TestClient.connect(String _url, String token)

Properties

client ↔ Client
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String
latefinal

Methods

createSubTask(dynamic task) → Future<String>
disconnect() → void
getIdentity() → Future
getProcessedTests() → Future<Set<String>>
getTask() → Future
graphQLSend(String query, [dynamic variables]) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remoteAvailable() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited